package org.apache.bcel;

import org.apache.commons.lang3.ArrayUtils;

public final class ExceptionConst
{
    public static final Class<Throwable> THROWABLE;
    public static final Class<RuntimeException> RUNTIME_EXCEPTION;
    public static final Class<LinkageError> LINKING_EXCEPTION;
    public static final Class<ClassCircularityError> CLASS_CIRCULARITY_ERROR;
    public static final Class<ClassFormatError> CLASS_FORMAT_ERROR;
    public static final Class<ExceptionInInitializerError> EXCEPTION_IN_INITIALIZER_ERROR;
    public static final Class<IncompatibleClassChangeError> INCOMPATIBLE_CLASS_CHANGE_ERROR;
    public static final Class<AbstractMethodError> ABSTRACT_METHOD_ERROR;
    public static final Class<IllegalAccessError> ILLEGAL_ACCESS_ERROR;
    public static final Class<InstantiationError> INSTANTIATION_ERROR;
    public static final Class<NoSuchFieldError> NO_SUCH_FIELD_ERROR;
    public static final Class<NoSuchMethodError> NO_SUCH_METHOD_ERROR;
    public static final Class<NoClassDefFoundError> NO_CLASS_DEF_FOUND_ERROR;
    public static final Class<UnsatisfiedLinkError> UNSATISFIED_LINK_ERROR;
    public static final Class<VerifyError> VERIFY_ERROR;
    public static final Class<NullPointerException> NULL_POINTER_EXCEPTION;
    public static final Class<ArrayIndexOutOfBoundsException> ARRAY_INDEX_OUT_OF_BOUNDS_EXCEPTION;
    public static final Class<ArithmeticException> ARITHMETIC_EXCEPTION;
    public static final Class<NegativeArraySizeException> NEGATIVE_ARRAY_SIZE_EXCEPTION;
    public static final Class<ClassCastException> CLASS_CAST_EXCEPTION;
    public static final Class<IllegalMonitorStateException> ILLEGAL_MONITOR_STATE;
    private static final Class<?>[] EXCS_CLASS_AND_INTERFACE_RESOLUTION;
    private static final Class<?>[] EXCS_FIELD_AND_METHOD_RESOLUTION;
    private static final Class<?>[] EXCS_INTERFACE_METHOD_RESOLUTION;
    private static final Class<?>[] EXCS_STRING_RESOLUTION;
    private static final Class<?>[] EXCS_ARRAY_EXCEPTION;
    
    public static Class<?>[] createExceptions(final EXCS type, final Class<?>... extraClasses) {
        switch (type) {
            case EXCS_CLASS_AND_INTERFACE_RESOLUTION: {
                return mergeExceptions(ExceptionConst.EXCS_CLASS_AND_INTERFACE_RESOLUTION, extraClasses);
            }
            case EXCS_ARRAY_EXCEPTION: {
                return mergeExceptions(ExceptionConst.EXCS_ARRAY_EXCEPTION, extraClasses);
            }
            case EXCS_FIELD_AND_METHOD_RESOLUTION: {
                return mergeExceptions(ExceptionConst.EXCS_FIELD_AND_METHOD_RESOLUTION, extraClasses);
            }
            case EXCS_INTERFACE_METHOD_RESOLUTION: {
                return mergeExceptions(ExceptionConst.EXCS_INTERFACE_METHOD_RESOLUTION, extraClasses);
            }
            case EXCS_STRING_RESOLUTION: {
                return mergeExceptions(ExceptionConst.EXCS_STRING_RESOLUTION, extraClasses);
            }
            default: {
                throw new AssertionError((Object)("Cannot happen; unexpected enum value: " + type));
            }
        }
    }
    
    private static Class<?>[] mergeExceptions(final Class<?>[] input, final Class<?>... extraClasses) {
        return (Class[])ArrayUtils.addAll((Object[])input, (Object[])extraClasses);
    }
    
    static {
        THROWABLE = Throwable.class;
        RUNTIME_EXCEPTION = RuntimeException.class;
        LINKING_EXCEPTION = LinkageError.class;
        CLASS_CIRCULARITY_ERROR = ClassCircularityError.class;
        CLASS_FORMAT_ERROR = ClassFormatError.class;
        EXCEPTION_IN_INITIALIZER_ERROR = ExceptionInInitializerError.class;
        INCOMPATIBLE_CLASS_CHANGE_ERROR = IncompatibleClassChangeError.class;
        ABSTRACT_METHOD_ERROR = AbstractMethodError.class;
        ILLEGAL_ACCESS_ERROR = IllegalAccessError.class;
        INSTANTIATION_ERROR = InstantiationError.class;
        NO_SUCH_FIELD_ERROR = NoSuchFieldError.class;
        NO_SUCH_METHOD_ERROR = NoSuchMethodError.class;
        NO_CLASS_DEF_FOUND_ERROR = NoClassDefFoundError.class;
        UNSATISFIED_LINK_ERROR = UnsatisfiedLinkError.class;
        VERIFY_ERROR = VerifyError.class;
        NULL_POINTER_EXCEPTION = NullPointerException.class;
        ARRAY_INDEX_OUT_OF_BOUNDS_EXCEPTION = ArrayIndexOutOfBoundsException.class;
        ARITHMETIC_EXCEPTION = ArithmeticException.class;
        NEGATIVE_ARRAY_SIZE_EXCEPTION = NegativeArraySizeException.class;
        CLASS_CAST_EXCEPTION = ClassCastException.class;
        ILLEGAL_MONITOR_STATE = IllegalMonitorStateException.class;
        EXCS_CLASS_AND_INTERFACE_RESOLUTION = new Class[] { ExceptionConst.NO_CLASS_DEF_FOUND_ERROR, ExceptionConst.CLASS_FORMAT_ERROR, ExceptionConst.VERIFY_ERROR, ExceptionConst.ABSTRACT_METHOD_ERROR, ExceptionConst.EXCEPTION_IN_INITIALIZER_ERROR, ExceptionConst.ILLEGAL_ACCESS_ERROR };
        EXCS_FIELD_AND_METHOD_RESOLUTION = new Class[] { ExceptionConst.NO_SUCH_FIELD_ERROR, ExceptionConst.ILLEGAL_ACCESS_ERROR, ExceptionConst.NO_SUCH_METHOD_ERROR };
        EXCS_INTERFACE_METHOD_RESOLUTION = new Class[0];
        EXCS_STRING_RESOLUTION = new Class[0];
        EXCS_ARRAY_EXCEPTION = new Class[] { ExceptionConst.NULL_POINTER_EXCEPTION, ExceptionConst.ARRAY_INDEX_OUT_OF_BOUNDS_EXCEPTION };
    }
    
    public enum EXCS
    {
        EXCS_CLASS_AND_INTERFACE_RESOLUTION, 
        EXCS_FIELD_AND_METHOD_RESOLUTION, 
        EXCS_INTERFACE_METHOD_RESOLUTION, 
        EXCS_STRING_RESOLUTION, 
        EXCS_ARRAY_EXCEPTION;
    }
}
